<template>
  <Calendar v-model="queryState.date"></Calendar>
  <ProTabs
    v-model="queryState.status"
    name="task-tab"
    :showPaneContent="false"
    class="task-tabs"
    isTransparent
    title-gutter="8"
    title-scroll
  >
    <ProTabPane :title="`待提交`" :pane-key="10"></ProTabPane>
    <ProTabPane :title="`待验收`" :pane-key="20"></ProTabPane>
  </ProTabs>
  <InfiniteLoading
    scrollViewClassName="common-infinite-scroll-list task-list"
    v-bind="infiniteLoadingProps"
    :key="queryState.status"
  >
    <template #renderItem="{ item }">
      <MyTaskCard @click="goSubmitTaskDetail(item)" />
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { MyTaskCard, ProTabs, ProTabPane, Calendar } from '@12333/components';
import Taro from '@tarojs/taro';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';

defineOptions({
  name: 'InnerPage',
});

const queryState = reactive({
  status: 10,
  date: new Date(),
});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetFlexTaskListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'lastShelfTime', order: OrderInputType.Desc }],
      },
    };

    return flexWorkerServices.getFlexTaskByArrange(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['flexWorkerServices/getFlexTaskByArrange', queryState],
  }
);

function goSubmitTaskDetail(item: API.GetFlexTaskListOutput) {
  //   Taro.navigateTo({
  //     url: `${RouterPath.taskSubmitCheck}?id=${item.id}`,
  //   });
  Taro.navigateTo({
    url: `${RouterPath.taskCheckDetail}?id=${item.taskId}`,
  });
}
</script>

<style lang="scss">
@import '@/styles/common.scss';

.task-list {
  @include infiniteLoadingInTabBarPage;
}
</style>
